//-*-c++-*-

// ======================================
//  NAME    : UKL1 Script
//
//  VERSION : 0
//
//  REVISION: 1
//
//  DATE    : 2006/OCT/12
//
//  RELEASE : 2006/
//
//  PLATFORM: PVSS II
//
//  AUTHOR  : Gareth Rogers
//
//  EMAIL   : rogers@hep.phy.cam.ac.uk
// ======================================

/*! \mainpage UKL1 Scripts Documentation
 *
 *  Modifications: none
 *
 *  PVSS manager usage: VISION, CTRL
 */// ======================================

/*!
 * This function is used to update the state machine text on the BoardInterface panel.
 *
 * \param  state The state that should be displayed. Must be of the types defined in the UKL1 library.
 * \return int An error code indicating if the operation was successful. The codes are as follows:
 *   \li  0 Execution proceeded without a problem, the state has been updated on the panel.
 *   \li -1 Execution failed and the state has not been updated on the panel due to a PVSS problem.
 *   \li  1 Execution failed and the state has not been updated on the panel due to an unrecognised state.
 *
 * The board settings are not affected by this script, it is merely to update the panel information. Any failure
 * to complete the function is not a result 
 */
void ukl1SetStateText(string state) {
  //Colour that the text will be.
  string textColour;
  if (ukl1UnconfiguredState == state) {
    textColour = "{255,0,0}";
  } else if (ukl1ReadyState == state) {
    textColour = "{255,255,0}";
  }else if (ukl1StartState == state) {
    textColour = "{0,255,0}";
  } else if (ukl1StopState == state) {
    textColour = "{255,255,0}";
  } else {
    //Any text that appears blue means something went horribly wrong!
    textColour = "{0,0,255}";
  }
  //Now set the status and the appropriate colour to go with it.
  setValue("CurrentStateText","text",state);
  setValue("CurrentStateText","backCol",textColour);
}//ukl1SetStateText
